summaryrefslogtreecommitdiffstats
path: root/docs
diff options
context:
space:
mode:
authorMichael E Brown <michael_e_brown@dell.com>2007-12-18 14:33:31 -0600
committerMichael E Brown <michael_e_brown@dell.com>2007-12-18 14:33:31 -0600
commit67e4534d8c571dacf85fde3d6dc11d66ba61c441 (patch)
treeea9490e3cc1d9c27048e8e6a10097efca24a044d /docs
parent012a5f92f24d196337f120e2c0cc1f0483089928 (diff)
downloadmock-67e4534d8c571dacf85fde3d6dc11d66ba61c441.tar.gz
mock-67e4534d8c571dacf85fde3d6dc11d66ba61c441.tar.xz
mock-67e4534d8c571dacf85fde3d6dc11d66ba61c441.zip
add unit tests for tmpfs plugin.
Diffstat (limited to 'docs')
-rwxr-xr-xdocs/runtests.sh6
1 files changed, 4 insertions, 2 deletions
diff --git a/docs/runtests.sh b/docs/runtests.sh
index 6ee01c5..0c8330a 100755
--- a/docs/runtests.sh
+++ b/docs/runtests.sh
@@ -87,9 +87,9 @@ if [ ! -f $CHROOT/tmp/\{quux,wibble\} ] || [ -f $CHROOT/tmp/quux ] || [ -f $CHRO
fi
#
# Test offline build
#
-time $MOCKCMD --offline --rebuild $MOCKSRPM
+time $MOCKCMD --offline --enable-plugin=tmpfs --rebuild $MOCKSRPM
if [ ! -e $outdir/mock-*.x86_64.rpm ]; then
echo "rebuild test FAILED. could not find $outdir/mock-*.x86_64.rpm"
exit 1
@@ -166,6 +166,8 @@ fi
# Test build all configs we ship.
#
for i in $(ls etc/mock | grep .cfg | grep -v default | grep -v ppc); do
+ # test tmpfs and normal
+ time sudo ./py/mock.py --resultdir=$outdir --uniqueext=$uniqueext --enable-plugin=tmpfs --rebuild $MOCKSRPM -r $(basename $i .cfg) $MOCK_EXTRA_ARGS
time sudo ./py/mock.py --resultdir=$outdir --uniqueext=$uniqueext rebuild $MOCKSRPM -r $(basename $i .cfg) $MOCK_EXTRA_ARGS
done
@@ -87,9 +87,9 @@ if [ ! -f $CHROOT/tmp/\{quux,wibble\} ] || [ -f $CHROOT/tmp/quux ] || [ -f $CHRO
fi
#
-# Test offline build
+# Test offline build as well as tmpfs
#